==> viha-5.15.tar.gz: viha-5.15/tilanne.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Tilanne</title>
 <meta HTTP-EQUIV=\"Refresh\" CONTENT=15></head>
" . body_bgcolor() . "
";

$conf = get_nro('conf');
if ($conf == '') {
  $conf = s('tilanne-conf');
} else {
  $_SESSION[$prefix . 'tilanne-conf'] = $conf;
}

switch ($conf) {
 case 1:
   $hide_finished = false;
   $columns = 3;
   $bottom = 1;
   $side = 0;
   break;
 case 2:
   $hide_finished = false;
   $columns = 4;
   $bottom = 1;
   $side = 1;
   break;
 case 10:
   $hide_finished = true;
   $columns = 2;
   $bottom = 0;
   $side = 0;
   break;
 case 11:
   $hide_finished = true;
   $columns = 3;
   $bottom = 1;
   $side = 0;
   break;
 case 12:
   $hide_finished = true;
   $columns = 4;
   $bottom = 1;
   $side = 1;
   break;
 default:
   $hide_finished = false;
   $columns = 2;
   $bottom = 0;
   $side = 0;
 }

$now = date('Y-m-d H:i:s');

echo "<h1>" . ota_paivystys_nimi() . ", tilanne, $now</h1>\n";

if ($bottom == 0) {
  taktiset_linkit();
}

echo "<p><a href=\"tilanne-taysi.php\">Ryhmt</a> ";
if ($hide_finished)
  echo ", lopettaneet piilotettu\n";

echo "<br>A = Aikaleima (d:hh:mm) viime pivityksest, V = Ryhmn vahvuus,"
. " K = ryhmll olevien kirjausten mr,"
. " [V] = Verkko, [K] = koordinaatit\n";

echo "<br>Oletusverkko: " . ota_oletus_verkko()
. ", vahvuus " . ota_vahvuus(s('paivystys'))
. " joista paikalla " . ota_paikalla(s('paivystys'));
if ($hide_finished)
  $and_where = "AND ryhma_tila_id != 12"; # lopettanut
else
  $and_where = "";
$from_where_order =
  "FROM ryhma,paikka,ryhma_tila,verkko
   WHERE ryhma_tila_id = ryhma_tila.id AND paikka_id = paikka.id
         AND verkko_id = verkko.id
         AND (ryhma.paivystys_id = " . s("paivystys") . "
              OR (ryhma.alue_id = " . s("alue") . "
                  AND ryhma.paivystys_id = 2)
              OR ryhma.alue_id = 2)
         $and_where
   ORDER BY pri";
$items =
  ota_yksi("SELECT COUNT(*) $from_where_order");
$percol = intval(floor(($items + $columns - 1) / $columns));
$sql =
  "SELECT ryhma.ts,ryhma.id,kutsu,koordinaatit,ryhma_tila,paikka,verkko
   $from_where_order";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table align=top>
  <tr valign=top>";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
    . tr_bgcolor() 
	. "<th>A<th>Ryhm [V]<th>Tila<th>Sijainti [K]<th>V<th>K\n";
    }
    $a_id = $a['id'];
    $vahv =
      ota_yksi("SELECT COUNT(*)
                FROM hlo
                WHERE ryhma_id = $a_id
                AND paivystys_id = " . s("paivystys"));
    $kirj =
      ota_yksi("SELECT COUNT(*)
                FROM tap
                WHERE ryhma_id = $a_id");
    $ts = $a['ts'];
    $ts_diff = '';
    if ($a_id != 1)
      $ts_diff =
	m_ddhhmm(ota_yksi("select timestampdiff(minute,'$ts','$now')"));
    echo "    <tr>",
      "<td align=\"right\">$ts_diff",
      "<TD><a href=\"tilanne-taysi.php?id=$a_id\">$a[kutsu]"
      . muotoile_verkko($a['verkko'], $a['id'])
      . "</a>",
      "<TD><a href=\"ryhma-takt-1.php?id=$a_id\">$a[ryhma_tila]</a>",
      "<TD>$a[paikka]", muotoile_koordinaatit($a['koordinaatit']),
      "<TD>$vahv",
      "<td>$kirj";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "</table>\n";
    }
    $n ++;
  }
  echo "</TABLE>\n";
 } else {
  echo "<P>Plop. Ei ryhmtietoja.";
 }

$laitteet =
  ota_yksi("SELECT COUNT(*)
            FROM laite
            WHERE paivystys_id = " . s("paivystys"));
if ($laitteet > 0) {
  # nyt viestikalusto vain jos sit on
  echo "<p><a href=\"tilanne-kalusto.php\">Viestikalusto</a>,
Op = operaatiossa, K = kytss, V = vapaana\n";

  $items =
    ota_yksi("SELECT COUNT(DISTINCT laite_tyyppi_id)
              FROM laite
              WHERE paivystys_id = " . s("paivystys"));
  $percol = intval(floor(($items + $columns - 1) / $columns));
  $sql = "SELECT id,laite_tyyppi FROM laite_tyyppi ORDER BY laite_tyyppi";
  $result = my_mysql_query($sql);
  if ($result) {
    echo "
<table align=top>
  <tr valign=top>";
    $n = 0;
    while ($a = mysql_fetch_array($result)) {
      $a_id = $a['id'];
      $operaatiossa =
	ota_yksi("SELECT COUNT(*)
                  FROM laite
                  WHERE laite_tyyppi_id = $a_id
                        AND paivystys_id = " . s("paivystys"));
      if ($operaatiossa > 0) {
	# nyt vain jos on nytettv
	if (($n % $percol) == 0) {
	  echo "
  <td align=top>
  <table border=1>"
	    . tr_bgcolor() 
	    . "<th>Tyyppi<th>Op<th>K<th>V\n";
	}
	$kaytossa =
	  ota_yksi("SELECT COUNT(*)
                    FROM laite
                    WHERE laite_tyyppi_id = $a_id
                          AND ryhma_id != 1
                          AND paivystys_id = " . s("paivystys"));
	$vapaana =
	  ota_yksi("SELECT COUNT(*)
                    FROM laite
                    WHERE laite_tyyppi_id = $a_id
                          AND ryhma_id = 1
                          AND paivystys_id = " . s("paivystys"));
	echo "  <tr><TD>$a[laite_tyyppi]",
	  "<TD>$operaatiossa",
	  "<TD>$kaytossa",
	  "<td>$vapaana";
	if ((($n % $percol) == ($percol - 1))
	    || ($n == ($items - 1))) {
	  echo "</table>\n";
	}
	$n ++;
      } # operaatiossa > 0
    }
    echo "</TABLE>\n";
  } 
 } # laitteet > 0

$tavara_op =
  ota_yksi("SELECT COUNT(*)
            FROM tavara
            WHERE paivystys_id = " . s("paivystys"));
if ($tavara_op > 0) {
  # nyt kalusto vain jos sit on
  $tavara_k =
    ota_yksi("SELECT COUNT(*)
              FROM tavara
              WHERE ryhma_id != 1
                    AND paivystys_id = " . s("paivystys"));
  $tavara_v =
    ota_yksi("SELECT COUNT(*)
              FROM tavara
              WHERE ryhma_id = 1
                    AND paivystys_id = " . s("paivystys"));
  echo "<p><a href=\"tilanne-kalusto.php\">Muu kalusto</a>:
Operaatiossa $tavara_op, kytss $tavara_k, vapaana $tavara_v\n";
 } # tavara_op > 0

# Ei nayteta kadonneita eik lytyneit jos kumpiakaan ei ole
$n_kadonneet_loytyneet = ota_kadonneet() + ota_loytyneet();
if ($n_kadonneet_loytyneet > 0) {
  if ($side) {
    print "<table><tr valign=top><td>";
  }
  echo "<p><a href=\"lapset-taysi.php\">Kateissa olevat henkilt</a>\n";
  $table = "kadonnut";
  $sql =
    "SELECT $table.id,$table.ts,lapsi_tila,viimeksi_kello,kello,nimi,ika,
            sukupuoli
     FROM $table,lapsi_tila
     WHERE lapsi_tila_id = lapsi_tila.id
           AND (lapsi_tila.id = 2 OR lapsi_tila.id = 3)
           AND $table.paivystys_id = " . s("paivystys") . "
     ORDER BY $table.ts";
  $result = my_mysql_query($sql);
  if ($result) {
    echo "<TABLE BORDER=1>\n";
    echo tr_bgcolor()
      . "<TH>Id<TH>Tila<TH>Viimeinen<br>havainto<th>SPR:n<br>tietoon<TH>Nimi"
      . "<TH>Ik<TH>Sukupuoli\n";
    while ($a = mysql_fetch_array($result)) {
      echo "<TR><TD>$a[id]",
	"<TD>$a[lapsi_tila]",
	"<TD align=right>", vain_hhmm($a['viimeksi_kello']),
	"<TD align=right>", vain_hhmm($a['kello']),
	"<TD>$a[nimi]",
	"<TD>$a[ika]",
	"<TD>$a[sukupuoli]";
      echo "<td><a href=\"$table.php?id=$a[id]&show=NYT\">NYT</a>\n";
    }
    echo "</TABLE>";
  } else {
    echo "<P>Plop. Ei kadonneiden tietoja.";
  }

  if ($side) {
    print "<td>";
  }
  echo "<p><a href=\"lapset-taysi.php\">Lytyneet henkilt</a>\n";
  $table = "loytynyt";
  $sql =
    "SELECT $table.id,$table.ts,lapsi_tila,kello,nimi,ika,sukupuoli
     FROM $table,lapsi_tila
     WHERE lapsi_tila_id = lapsi_tila.id
           AND (lapsi_tila.id = 2 OR lapsi_tila.id = 3)
           AND $table.paivystys_id = " . s("paivystys") . "
     ORDER BY $table.ts";
  $result = my_mysql_query($sql);
  if ($result) {
    echo "<TABLE BORDER=1>\n";
    echo tr_bgcolor()
      . "<TH>Id<TH>Tila<TH>SPR:n<br>tietoon<TH>Nimi<TH>Ik<TH>Sukupuoli\n";
    while ($a = mysql_fetch_array($result)) {
      echo "<TR><TD>$a[id]",
	"<TD>$a[lapsi_tila]",
	"<TD align=right>", vain_hhmm($a['kello']),
	"<TD>$a[nimi]",
	"<TD>$a[ika]", "<TD>$a[sukupuoli]";
      echo "<td><a href=\"$table.php?id=$a[id]&show=NYT\">NYT</a>\n";
    }
    echo "</TABLE>";
  } else {
    echo "<P>Plop. Ei kadonneiden tietoja.";
  }
  if ($side) {
    print "</table>";
  }
 } else {
  echo "<p>Ei kadonneita eik lytyneit.\n";
 }

echo "<p><a href=\"taktinen-loki.php\">Tapahtumapivkirja</a>,
kymmenen tuoreinta, uusimmat ensin";
$nayta_kpl = 10;
$result =
  my_mysql_query("SELECT *
                  FROM taktinen_loki
                  WHERE paivystys_id = " . s("paivystys") . "
                  ORDER BY ts DESC
                  LIMIT 0, $nayta_kpl");
if ($result) {
  echo "<TABLE BORDER=1>\n";
  echo tr_bgcolor() 
    . "<TH>Kello<TH>Tunnus<TH>Tapahtuma\n";
  while ($a = mysql_fetch_array($result)) {
    echo "<TR>",
      "<TD align=right>" . vain_hhmm($a['ts']),
      "<TD>$a[user]",
      "<TD>$a[data]";
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei lokia.";
 }
    
if ($bottom == 1) {
  taktiset_linkit();
}

echo "
<ul>Vaihtoehtoisia nkymi thn sivuun
<li><a href=\"tilanne.php?conf=0\">
 Ryhmt ja viestikalusto 2 sarakkeessa,
 kadonneet ja lytyneet perkkin,
 linkit ylhll (oletus).
 </a>
<li><a href=\"tilanne.php?conf=1\">
 Ryhmt ja viestikalusto 3 sarakkeessa,
 kadonneet ja lytyneet perkkin,
 linkit alhaalla.
 </a>
<li><a href=\"tilanne.php?conf=2\">
 Ryhmt ja viestikalusto 4 sarakkeessa,
 kadonneet ja lytyneet rinnakkain,
 linkit alhaalla.
 </a>
<li><a href=\"tilanne.php?conf=10\">
 Ryhmt ja viestikalusto 2 sarakkeessa,
 kadonneet ja lytyneet perkkin,
 linkit ylhll, piilota lopettaneet.
 </a>
<li><a href=\"tilanne.php?conf=11\">
 Ryhmt ja viestikalusto 3 sarakkeessa,
 kadonneet ja lytyneet perkkin,
 linkit alhaalla, piilota lopettaneet.
 </a>
<li><a href=\"tilanne.php?conf=12\">
 Ryhmt ja viestikalusto 4 sarakkeessa,
 kadonneet ja lytyneet rinnakkain,
 linkit alhaalla, piilota lopettaneet.
 </a>
</ul>

<p>Tm sivu pivittyy automaattisesti 15 sekunnin vlein.";

loppu();

?>

</body> 
</html>

<!-- RCS $Id: tilanne.php,v 1.23 2009/06/07 06:30:39 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tilanne.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>ViHa - Tilanne</title>
 <meta HTTP-EQUIV=\"Refresh\" CONTENT=15></head>
" . body_bgcolor() . "
";

$conf = get_nro('conf');
if ($conf == '') {
  $conf = s('tilanne-conf');
} else {
  $_SESSION[$prefix . 'tilanne-conf'] = $conf;
}

switch ($conf) {
 case 1:
   $hide_finished = false;
   $columns = 3;
   $bottom = 1;
   break;
 case 2:
   $hide_finished = false;
   $columns = 4;
   $bottom = 1;
   break;
 case 10:
   $hide_finished = true;
   $columns = 2;
   $bottom = 0;
   break;
 case 11:
   $hide_finished = true;
   $columns = 3;
   $bottom = 1;
   break;
 case 12:
   $hide_finished = true;
   $columns = 4;
   $bottom = 1;
   break;
 default:
   $hide_finished = false;
   $columns = 2;
   $bottom = 0;
 }

$now = date('Y-m-d H:i:s');

echo "<h1>" . muotoile_operaatio() . ", tilanne klo "
. vain_hhmm($now) . "</h1>\n";

if ($bottom == 0) {
  taktiset_linkit();
}

echo "<p><a href=\"tilanne-taysi.php\">Ryhmt</a> ";
if ($hide_finished)
  echo ", lopettaneet piilotettu\n";

echo "<br>A = Aikaleima (d:hh:mm) viime pivityksest, V = Ryhmn vahvuus,"
. " K = ryhmll olevien kirjausten mr,"
. " [V] = Verkko, [K] = koordinaatit\n";

echo "<br>Oletusverkko: " . ota_oletus_verkko()
. ", vahvuus " . ota_vahvuus(s('paivystys'))
. " joista paikalla " . ota_paikalla(s('paivystys'));
if ($hide_finished)
  $and_where = "AND ryhma_tila_id != 12"; # lopettanut
else
  $and_where = "";
$from_where_order =
  "FROM ryhma,paikka,ryhma_tila,verkko
   WHERE ryhma_tila_id = ryhma_tila.id AND paikka_id = paikka.id
         AND verkko_id = verkko.id
         AND (ryhma.paivystys_id = " . s("paivystys") . "
              OR (ryhma.alue_id = " . s("alue") . "
                  AND ryhma.paivystys_id = 2)
              OR ryhma.alue_id = 2)
         $and_where
   ORDER BY pri";
$items =
  ota_yksi("SELECT COUNT(*) $from_where_order");
$percol = intval(floor(($items + $columns - 1) / $columns));
$sql =
  "SELECT ryhma.ts,ryhma.id,kutsu,koordinaatit,ryhma_tila,paikka,verkko
   $from_where_order";
$result = my_mysql_query($sql);
if ($result) {
  echo "
<table align=top>
  <tr valign=top>";
  $n = 0;
  while ($a = mysql_fetch_array($result)) {
    if (($n % $percol) == 0) {
      echo "
  <td align=top>
  <table border=1>"
    . tr_vaalsin() 
	. "<th>A<th>Ryhm [V]<th>Tila<th>Sijainti [K]<th>V<th>K\n";
    }
    $a_id = $a['id'];
    $vahv =
      ota_yksi("SELECT COUNT(*)
                FROM hlo
                WHERE ryhma_id = $a_id
                AND paivystys_id = " . s("paivystys"));
    $kirj =
      ota_yksi("SELECT COUNT(*)
                FROM tap
                WHERE ryhma_id = $a_id");
    $ts = $a['ts'];
    $ts_diff = '';
    $ts_min = 0;
    if ($a_id != 1) {
      $ts_min = ota_yksi("select timestampdiff(minute,'$ts','$now')");
      $ts_diff = m_ddhhmm($ts_min);
    }
    echo "<tr>",
      "<td align=\"right\">$ts_diff";
    if ($ts_min < 60)
      echo "<TD>";
    else
      echo "<TD BGCOLOR=\"YELLOW\">";
    echo
      "<a href=\"tilanne-taysi.php?id=$a_id\">$a[kutsu]"
      . muotoile_verkko($a['verkko'], $a['id'])
      . "</a>",
      "<TD><a href=\"ryhma-takt-1.php?id=$a_id\">$a[ryhma_tila]</a>",
      "<TD>$a[paikka]", muotoile_koordinaatit($a['koordinaatit']),
      "<TD>$vahv",
      "<td>$kirj";
    if ((($n % $percol) == ($percol - 1))
	|| ($n == ($items - 1))) {
      echo "</table>\n";
    }
    $n ++;
  }
  echo "</TABLE>\n";
 } else {
  echo "<P>Plop. Ei ryhmtietoja.";
 }

$laitteet =
  ota_yksi("SELECT COUNT(*)
            FROM laite
            WHERE paivystys_id = " . s("paivystys"));
if ($laitteet > 0) {
  # nyt viestikalusto vain jos sit on
  echo "<p><a href=\"tilanne-kalusto.php\">Viestikalusto</a>,
Op = operaatiossa, K = kytss, V = vapaana\n";

  $items =
    ota_yksi("SELECT COUNT(DISTINCT laite_tyyppi_id)
              FROM laite
              WHERE paivystys_id = " . s("paivystys"));
  $percol = intval(floor(($items + $columns - 1) / $columns));
  $sql = "SELECT id,laite_tyyppi FROM laite_tyyppi ORDER BY laite_tyyppi";
  $result = my_mysql_query($sql);
  if ($result) {
    echo "
<table align=top>
  <tr valign=top>";
    $n = 0;
    while ($a = mysql_fetch_array($result)) {
      $a_id = $a['id'];
      $operaatiossa =
	ota_yksi("SELECT COUNT(*)
                  FROM laite
                  WHERE laite_tyyppi_id = $a_id
                        AND paivystys_id = " . s("paivystys"));
      if ($operaatiossa > 0) {
	# nyt vain jos on nytettv
	if (($n % $percol) == 0) {
	  echo "
  <td align=top>
  <table border=1>"
	    . tr_vaalsin() 
	    . "<th>Tyyppi<th>Op<th>K<th>V\n";
	}
	$kaytossa =
	  ota_yksi("SELECT COUNT(*)
                    FROM laite
                    WHERE laite_tyyppi_id = $a_id
                          AND ryhma_id != 1
                          AND paivystys_id = " . s("paivystys"));
	$vapaana =
	  ota_yksi("SELECT COUNT(*)
                    FROM laite
                    WHERE laite_tyyppi_id = $a_id
                          AND ryhma_id = 1
                          AND paivystys_id = " . s("paivystys"));
	echo "  <tr><TD>$a[laite_tyyppi]",
	  "<TD>$operaatiossa",
	  "<TD>$kaytossa",
	  "<td>$vapaana";
	if ((($n % $percol) == ($percol - 1))
	    || ($n == ($items - 1))) {
	  echo "</table>\n";
	}
	$n ++;
      } # operaatiossa > 0
    }
    echo "</TABLE>\n";
  } 
 } # laitteet > 0

$tavara_op =
  ota_yksi("SELECT COUNT(*)
            FROM tavara
            WHERE paivystys_id = " . s("paivystys"));
if ($tavara_op > 0) {
  # nyt kalusto vain jos sit on
  $tavara_k =
    ota_yksi("SELECT COUNT(*)
              FROM tavara
              WHERE ryhma_id != 1
                    AND paivystys_id = " . s("paivystys"));
  $tavara_v =
    ota_yksi("SELECT COUNT(*)
              FROM tavara
              WHERE ryhma_id = 1
                    AND paivystys_id = " . s("paivystys"));
  echo "<p><a href=\"tilanne-kalusto.php\">Muu kalusto</a>:
Operaatiossa $tavara_op, kytss $tavara_k, vapaana $tavara_v\n";
 } # tavara_op > 0

# Ei nayteta kadonneita jos ei ole
 
$n_kadonneet = ota_kadonneet();
if ($n_kadonneet > 0) {
  echo "<p><a href=\"lapset-taysi.php\">Kateissa olevat henkilt</a>\n";
  $table = "kadonnut";
  $sql =
    "SELECT $table.id,$table.ts,lapsi_tila,viimeksi_kello,kello,nimi,ika,
            sukupuoli
     FROM $table,lapsi_tila
     WHERE lapsi_tila_id = lapsi_tila.id
           AND (lapsi_tila.id = 2 OR lapsi_tila.id = 3)
           AND $table.paivystys_id = " . s("paivystys") . "
     ORDER BY $table.ts";
  $result = my_mysql_query($sql);
  if ($result) {
    echo "<TABLE BORDER=1>\n";
    tr_reset();
    echo tr_vaalsin()
      . "<TH>Id<TH>Tila<TH>Viimeinen<br>havainto<th>Tullut<br>tietoon<TH>Nimi"
      . "<TH>Ik<TH>Sukupuoli\n";
    while ($a = mysql_fetch_array($result)) {
      echo tr() . "<TD>$a[id]",
	"<TD><a href=\"$table.php?id=$a[id]&change=MUUTA\">$a[lapsi_tila]</a>",
	"<TD align=right>", vain_hhmm($a['viimeksi_kello']),
	"<TD align=right>", vain_hhmm($a['kello']),
	"<TD>$a[nimi]",
	"<TD>$a[ika]",
	"<TD>$a[sukupuoli]";
    }
    echo "</TABLE>";
  } else {
    echo "<P>Plop. Ei kadonneiden tietoja.";
  }
 } # kadonneet

echo "<p><a href=\"taktinen-loki.php\">Tapahtumapivkirja</a>,
kymmenen tuoreinta, uusimmat ensin";
$nayta_kpl = 10;
$result =
  my_mysql_query("SELECT *
                  FROM taktinen_loki
                  WHERE paivystys_id = " . s("paivystys") . "
                  ORDER BY ts DESC
                  LIMIT 0, $nayta_kpl");
if ($result) {
  echo "<TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin() 
    . "<TH>Kello<TH>Tunnus<TH>Tapahtuma\n";
  while ($a = mysql_fetch_array($result)) {
    echo tr() . "",
      "<TD align=right>" . vain_hhmm($a['ts']),
      "<TD>$a[user]",
      "<TD>$a[data]";
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei lokia.";
 }
    
if ($bottom == 1) {
  taktiset_linkit();
}

echo "
<ul>Vaihtoehtoisia nkymi thn sivuun
<li><a href=\"tilanne.php?conf=0\">
 Ryhmt ja viestikalusto 2 sarakkeessa,
 linkit ylhll (oletus).
 </a>
<li><a href=\"tilanne.php?conf=1\">
 Ryhmt ja viestikalusto 3 sarakkeessa,
 linkit alhaalla.
 </a>
<li><a href=\"tilanne.php?conf=2\">
 Ryhmt ja viestikalusto 4 sarakkeessa,
 linkit alhaalla.
 </a>
<li><a href=\"tilanne.php?conf=10\">
 Ryhmt ja viestikalusto 2 sarakkeessa,
 linkit ylhll, piilota lopettaneet.
 </a>
<li><a href=\"tilanne.php?conf=11\">
 Ryhmt ja viestikalusto 3 sarakkeessa,
 linkit alhaalla, piilota lopettaneet.
 </a>
<li><a href=\"tilanne.php?conf=12\">
 Ryhmt ja viestikalusto 4 sarakkeessa,
 linkit alhaalla, piilota lopettaneet.
 </a>
</ul>

<p>Tm sivu pivittyy automaattisesti 15 sekunnin vlein.";

loppu();

?>

</body> 
</html>

<!-- RCS $Id: tilanne.php,v 1.29 2009/10/05 11:12:49 riku Exp $ -->
